@@ -1,11 +1,12 @@
 # -*- coding: UTF-8 -*-
 """Date Parse Utility Tests"""
 from datetime import datetime
+from dateutil.tz import tzutc
 from parser import ParserError
 
 import pytest
 
-from hdx.utilities.dateparse import parse_date_range, parse_date, get_date_from_timestamp
+from hdx.utilities.dateparse import parse_date_range, parse_date, get_datetime_from_timestamp, get_timestamp_from_datetime
 
 
 class TestDateParse:
@@ -71,6 +72,12 @@ class TestDateParse:
         with pytest.raises(ParserError):
             parse_date('02/2013', '%m/%Y')
 
-    def test_get_date_from_timestamp(self):
-        assert get_date_from_timestamp(1596180834) == datetime(2020, 7, 31, 9, 33, 54)
-        assert get_date_from_timestamp(1596180834000) == datetime(2020, 7, 31, 9, 33, 54)
\ No newline at end of file
+    def test_get_datetime_from_timestamp(self):
+        expected_timestamp = 1596180834.0
+        expected_date = datetime(2020, 7, 31, 7, 33, 54, tzinfo=tzutc())
+        timestamp = get_timestamp_from_datetime(expected_date)
+        assert timestamp == expected_timestamp
+        date = get_datetime_from_timestamp(expected_timestamp, timezone=tzutc())
+        assert date == expected_date
+        date = get_datetime_from_timestamp(expected_timestamp * 1000, timezone=tzutc())
+        assert date == expected_date
